---
layout: doc
title: Themes
categories: themes
permalink: /themes/list
---

A list of awesome custom templates are available on this page. Themes files are available on CDNs, NPM, Bower and Github repository. 

Please refer to [Using themes]({{site.baseurl}}/themes/install) to read about the installation process.

#### Classic

<img src="https://raw.githubusercontent.com/usablica/intro.js/gh-pages/img/themes/classic.png" style="width: 100%;">

Current default IntroJS template.

#### Royal

<img src="https://raw.githubusercontent.com/usablica/intro.js/gh-pages/img/themes/royal.png" style="width: 100%;">

Fixed tooltip bar to footer.

#### Nassim

<img src="https://raw.githubusercontent.com/usablica/intro.js/gh-pages/img/themes/nassim.png" style="width: 100%;">

#### Nazanin

<img src="https://raw.githubusercontent.com/usablica/intro.js/gh-pages/img/themes/nazanin.png" style="width: 100%;">

#### Dark

<img src="https://raw.githubusercontent.com/usablica/intro.js/gh-pages/img/themes/dark.png" style="width: 100%;">

#### Modern

<img src="https://raw.githubusercontent.com/usablica/intro.js/gh-pages/img/themes/modern.png" style="width: 100%;">

